======
asciju
======


.. image:: https://img.shields.io/pypi/v/asciju.svg
        :target: https://pypi.python.org/pypi/asciju

.. image:: https://img.shields.io/travis/aju100/asciju.svg
        :target: https://travis-ci.com/aju100/asciju

.. image:: https://readthedocs.org/projects/asciju/badge/?version=latest
        :target: https://asciju.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python package that converts image to ascii


* Free software: MIT license
* Documentation: https://asciju.readthedocs.io.



Features
--------

* Conversion image to ASCII art

Roadmap
--------

* Text ASCII art
* Video conversion on ASCII Art
* Fix CLI argument parser
* Improved Documentation
* Unit Test

